==> finaluna-api-3.0.0.zip: finaluna-api/sources/jp/finaluna/api/type/StringType.java <==
/*
 * Copyright (C) 2010 NTT DATA Corporation.
 */

package jp.finaluna.api.type;

/**
 * ϕێ^B
 * 
 * <p>
 * ϕێBftHg̍ő啶50*1024*1024Bő啶𒴂ꍇAFinalunaSysExceptionthrowB
 * </p>
 * 
 * @version $Revision: 15138 $ $Date: 2009-01-17 02:38:48 +0900 $
 * @author NTTf[^
 */
@Rcsid("$Revision: 15138 $ $Date: 2009-01-17 02:38:48 +0900 $")
public interface StringType extends BaseType, CharSequenceType, Comparable < StringType >, Copiable < StringType > {

    /**
     * <p>
     * ̕CharSequenceType̕ǉB
     * </p>
     * 
     * @param value CharSequenceType^̕
     * @return ǉ̕
     */
    StringType append(CharSequenceType value);

    /**
     * <p>
     * ̐̕擪݂̂啶ɕϊB
     * </p>
     * 
     * @return ϊ
     */
    StringType capitalize();

    /**
     * <p>
     * ̎̕wʒu̕폜B̒l͎wʒu̕񂪍폜ꂽlƂȂB
     * </p>
     * 
     * @param start JnCfbNX
     * @param end ICfbNX
     * @return 폜̕
     */
    StringType delete(int start, int end);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽڔŏIĂ邩ǂ𔻒肷B
     * </p>
     * 
     * @param suffix ڔ
     * @return w肳ꂽڔŏIĂꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean endsWith(CharSequenceType suffix);

    /**
     * <p>
     * ̕񂪁ArΏۂ̕ƓǂA 啶A̋ʂȂɔ肷B
     * </p>
     * 
     * @param compareStr rΏە
     * @return rΏۂ̕ƓꍇA<code>true</code>A łȂꍇ <code>false</code>
     */
    boolean equalsIgnoreCase(CharSequenceType compareStr);

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @return CfbNX
     */
    int indexOf(CharSequenceType searchStr);

    /**
     * <p>
     * wCfbNXȍ~ŁA񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int indexOf(CharSequenceType searchStr, int fromIndex);

    /**
     * <p>
     * ̎̕wʒuɁACharSequenceType̕ǉB
     * </p>
     * 
     * @param index wʒuCfbNX
     * @param value CharSequenceType^̕
     * @return ǉ̕
     */
    StringType insert(int index, CharSequenceType value);

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\ĂꍇA<code>true</code>A łȂꍇ<code>false</code>
     */
    boolean isAlpha();

    /**
     * <p>
     * ̕񂪁Â݂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return ݂̂ō\ĂꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isNumeric();

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\ĂꍇA<code>true</code>A łȂꍇ<code>false</code>
     */
    boolean isNumericAlpha();

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŌɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchStr);

    /**
     * <p>
     * wCfbNXȑOŁA񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchStr, int fromIndex);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽK\ƈv邩ǂ𔻒肷B
     * </p>
     * 
     * @param regex K\
     * @return w肳ꂽK\ƈvꍇA <code>true</code>A łȂꍇ<code>false</code>
     */
    boolean matches(CharSequenceType regex);

    /**
     * <p>
     * w肵񂪁A̕ɑ݂邩ǂ𔻒肷B
     * </p>
     * 
     * @param searchStr 
     * @return Ɍ񂪑݂ꍇ <code>true</code>A łȂꍇ <code>false</code>
     */
    boolean search(CharSequenceType searchStr);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽړŎn܂邩ǂ𔻒肷B
     * </p>
     * 
     * @param prefix ړ
     * @return w肳ꂽړŎn܂ꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean startsWith(CharSequenceType prefix);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @return 
     */
    StringType subString(int beginIndex);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @param endIndex ̐؂oICfbNX
     * @return 
     */
    StringType subString(int beginIndex, int endIndex);

    /**
     * <p>
     * ̕AׂďɕϊB
     * </p>
     * 
     * @return ϊ
     */
    StringType toLowerCase();

    /**
     * <p>
     * ̕Aׂđ啶ɕϊB
     * </p>
     * 
     * @return ϊ
     */
    StringType toUpperCase();

    /**
     * <p>
     * ̐̕擪Ɩ̋󔒂菜^Ԃ܂B
     * </p>
     * 
     * @return Ő󔒂菜
     */
    StringType trim();

}

==> finaluna-api-3.2.0.zip: finaluna-api/sources/jp/finaluna/api/type/StringType.java <==
/*
 * Copyright (C) 2010 NTT DATA Corporation.
 */

package jp.finaluna.api.type;

/**
 * ϕێ^B
 * 
 * <p>
 * ϕێBftHg̍ő啶50*1024*1024Bő啶𒴂ꍇAFinalunaSysExceptionthrowB
 * </p>
 * 
 * @version $Revision: 15138 $ $Date: 2009-01-17 02:38:48 +0900 $
 * @author NTTf[^
 */
@Rcsid("$Revision: 15138 $ $Date: 2009-01-17 02:38:48 +0900 $")
public interface StringType extends BaseType, CharSequenceType, Comparable < StringType >, Copiable < StringType > {

    /**
     * <p>
     * ̕CharSequenceType̕ǉB
     * </p>
     * 
     * @param value CharSequenceType^̕
     * @return ǉ̕
     */
    StringType append(CharSequenceType value);

    /**
     * <p>
     * ̐̕擪݂̂啶ɕϊBϊΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @return ϊ
     */
    StringType capitalize();

    /**
     * <p>
     * ̎̕wʒu̕폜B̒l͎wʒu̕񂪍폜ꂽlƂȂB
     * </p>
     * 
     * @param start JnCfbNX
     * @param end ICfbNX
     * @return 폜̕
     */
    StringType delete(int start, int end);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽڔŏIĂ邩ǂ𔻒肷B
     * </p>
     * 
     * @param suffix ڔ
     * @return w肳ꂽڔŏIĂꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean endsWith(CharSequenceType suffix);

    /**
     * <p>
     * ̕񂪁ArΏۂ̕ƓǂA 啶A̋ʂȂɔ肷BrΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @param compareStr rΏە
     * @return rΏۂ̕ƓꍇA<code>true</code>A łȂꍇ <code>false</code>B
     */
    boolean equalsIgnoreCase(CharSequenceType compareStr);

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @return CfbNX
     */
    int indexOf(CharSequenceType searchStr);

    /**
     * <p>
     * wCfbNXȍ~ŁA񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int indexOf(CharSequenceType searchStr, int fromIndex);

    /**
     * <p>
     * ̎̕wʒuɁACharSequenceType̕ǉB
     * </p>
     * 
     * @param index wʒuCfbNX
     * @param value CharSequenceType^̕
     * @return ǉ̕
     */
    StringType insert(int index, CharSequenceType value);

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\ĂꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isAlpha();

    /**
     * <p>
     * ̕񂪁Â݂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return ݂̂ō\ĂꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isNumeric();

    /**
     * <p>
     * ̕񂪁Ap݂̂ō\Ă邩ǂ𔻒肷B
     * </p>
     * 
     * @return p݂̂ō\ĂꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean isNumericAlpha();

    /**
     * <p>
     * ̕ŁAw肳ꂽ񂪍ŌɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchStr);

    /**
     * <p>
     * wCfbNXȑOŁA񂪍ŏɏoʒũCfbNX 擾B
     * </p>
     * 
     * @param searchStr 
     * @param fromIndex JnCfbNX
     * @return oꂽCfbNX
     */
    int lastIndexOf(CharSequenceType searchStr, int fromIndex);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽK\ƈv邩ǂ𔻒肷B
     * </p>
     * 
     * @param regex K\
     * @return w肳ꂽK\ƈvꍇA <code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean matches(CharSequenceType regex);

    /**
     * <p>
     * w肵񂪁A̕ɑ݂邩ǂ𔻒肷B
     * </p>
     * 
     * @param searchStr 
     * @return Ɍ񂪑݂ꍇ <code>true</code>A łȂꍇ <code>false</code>B
     */
    boolean search(CharSequenceType searchStr);

    /**
     * <p>
     * ̕񂪁Aw肳ꂽړŎn܂邩ǂ𔻒肷B
     * </p>
     * 
     * @param prefix ړ
     * @return w肳ꂽړŎn܂ꍇA<code>true</code>A łȂꍇ<code>false</code>B
     */
    boolean startsWith(CharSequenceType prefix);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @return 
     */
    StringType subString(int beginIndex);

    /**
     * <p>
     * ̕̕ԂB
     * </p>
     * 
     * @param beginIndex ̐؂oJnCfbNX
     * @param endIndex ̐؂oICfbNX
     * @return 
     */
    StringType subString(int beginIndex, int endIndex);

    /**
     * <p>
     * ̕AׂďɕϊBϊΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @return ϊ
     */
    StringType toLowerCase();

    /**
     * <p>
     * ̕Aׂđ啶ɕϊBϊΏۂ̓̕At@xbĝ݂ƂB
     * </p>
     * 
     * @return ϊ
     */
    StringType toUpperCase();

    /**
     * <p>
     * ̐̕擪Ɩ̋󔒂菜^Ԃ܂B
     * </p>
     * 
     * @return Ő󔒂菜
     */
    StringType trim();

}
